==> dde-daemon_6.0.17.tar.xz: BUILD/misc/ts/org.deepin.dde.fprintd.policy/policy_sv.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sv" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="org.deepin.dde.fprintd.enroll!message" line="0"/>
			<source>Authentication is required to add fingerprint password</source>
			<translation>Autentisering krävs för att lägga till fingeravtryck</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.enroll!description" line="0"/>
			<source>Add fingerprint password</source>
			<translation>Lägg till fingeravtryck</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.delete-enrolled-fingers!message" line="0"/>
			<source>Authentication is required to clear fingerprint passwords</source>
			<translation>Autentisiering krävs för att radera fingeravtryck</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.delete-enrolled-fingers!description" line="0"/>
			<source>Clear fingerprint passwords</source>
			<translation>Radera fingeravtryck</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.rename-enrolled-finger!message" line="0"/>
			<source>Authentication is required to rename fingerprint password</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.rename-enrolled-finger!description" line="0"/>
			<source>Rename fingerprint password</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.manager!message" line="0"/>
			<source>Password is required to perform this action</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.manager!description" line="0"/>
			<source>Manage fingerprint passwords</source>
			<translation type="unfinished"/>
		</message>
	</context>
</TS>

==> dde-daemon_6.0.45.tar.xz: BUILD/misc/ts/org.deepin.dde.fprintd.policy/policy_sv.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sv" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="org.deepin.dde.fprintd.enroll!message" line="0"/>
			<source>Authentication is required to add fingerprint password</source>
			<translation>Autentisering krävs för att lägga till fingeravtryck</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.enroll!description" line="0"/>
			<source>Add fingerprint password</source>
			<translation>Lägg till fingeravtryck</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.delete-enrolled-fingers!message" line="0"/>
			<source>Authentication is required to clear fingerprint passwords</source>
			<translation>Autentisiering krävs för att radera fingeravtryck</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.delete-enrolled-fingers!description" line="0"/>
			<source>Clear fingerprint passwords</source>
			<translation>Radera fingeravtryck</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.rename-enrolled-finger!message" line="0"/>
			<source>Authentication is required to rename fingerprint password</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.rename-enrolled-finger!description" line="0"/>
			<source>Rename fingerprint password</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.manager!message" line="0"/>
			<source>Password is required to perform this action</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.manager!description" line="0"/>
			<source>Manage fingerprint passwords</source>
			<translation type="unfinished"/>
		</message>
	</context>
</TS>
